<?php
defined('BASEPATH') or exit('No direct script access allowed');

require_once(__DIR__ . '/../libraries/Picqer/autoload.php');

use Picqer\Barcode\Renderers\PngRenderer;
use Picqer\Barcode\Types\TypeCode128;


/* ============================
     Definição da Classe Pagou
   ============================ */
class Pagou extends AdminController
{
    /**
     * Método Construtor
     *
     * Inicializa o controlador Pagou com as dependências necessárias.
     */
    public function __construct()
{
    parent::__construct();
    $this->load->helper(['modules', 'url']); // Carrega o helper de módulos
    $this->load->database();
    $this->load->library('session');
    $this->load->model('invoices_model');
    $this->load->model('payments_model');
    $this->load->model('pagou_model');
}


    /**
     * Gera uma imagem de código de barras para o boleto.
     *
     * @param string $data Código de barras do boleto.
     */
    
    public function generate_barcode($data)
{
    // Configura cabeçalho para imagem PNG
    header('Content-Type: image/png');

    try {
        // Instancia o objeto TypeCode128
        $barcodeGenerator = new TypeCode128();
        $barcode = $barcodeGenerator->getBarcode($data); // Gera o código de barras

        // Configura o renderizador para PNG
        $renderer = new PngRenderer();

        // Gera e exibe o código de barras como imagem
        echo $renderer->render($barcode, 400, 100); // Ajuste os tamanhos conforme necessário
    } catch (Exception $e) {
        // Trata erros
        http_response_code(500);
        echo 'Erro ao gerar código de barras: ' . $e->getMessage();
    }
}

/**
     * Exibe a página de PIX Avulso
     */
    public function pix_avulso()
    {
        set_alert('warning', 'Funcionalidade Em Desenvolvimento');
        redirect(admin_url());
    }



 /**
     * Exibe a página de Cobranças Emitidas
     */
    public function cobrancas_emitidas()
    {
        $data['title'] = 'Cobranças Emitidas Invoice x Pagou';

        // Filtros para cobranças
        $filters = $this->input->post();
        $data['transactions'] = $this->pagou_model->get_transactions($filters);

        $this->load->view('admin/pagou/cobrancas_emitidas', $data);
    }

/**
     * Processa reembolsos de pagamentos
     */
    public function reembolso_ajax()
{
    // Início do processamento de reembolso
    log_message('info', 'Iniciando método reembolso_ajax.');

    // Lê o transaction_id via GET
    $transaction_id = $this->input->get('transaction_id');
    log_message('info', "Iniciando processamento de reembolso via AJAX DELETE para transaction_id: {$transaction_id}");

    // Lê o payload JSON do corpo da requisição DELETE
    $raw_input = file_get_contents('php://input');
    log_message('debug', "Raw input recebido: {$raw_input}");
    $payload   = json_decode($raw_input, true);

    // Verifica se transaction_id e payload estão presentes
    if (!$transaction_id || !$payload) {
        log_message('error', 'Faltam dados para processar reembolso. transaction_id ou payload ausentes.');
        echo json_encode(['status' => 'error', 'message' => 'Dados insuficientes para reembolso']);
        return;
    }

    // Extrai informações do payload
    $refund_amount = isset($payload['amount']) ? floatval($payload['amount']) : 0.0;
    $description   = isset($payload['description']) ? $payload['description'] : 'Sem motivo informado';
    $reason        = isset($payload['reason'])      ? intval($payload['reason']) : 1; // optional

    log_message('debug', "Dados do payload DELETE -> refund_amount: {$refund_amount}, description: {$description}, reason: {$reason}");

    // Busca detalhes da transação
    log_message('info', "Buscando detalhes da transação com ID: {$transaction_id}");
    $transaction = $this->pagou_model->get_transaction_by_id($transaction_id);
    if (!$transaction) {
        log_message('error', "Transação não encontrada para ID: {$transaction_id}");
        echo json_encode(['status' => 'error', 'message' => 'Transação não encontrada!']);
        return;
    }
    log_message('info', "Transação encontrada: " . json_encode($transaction));

    // Determina o identificador do QR Code / transaction_id
    $qrcodeid = !empty($transaction->qr_code) ? $transaction->qr_code : $transaction->transaction_id;
    log_message('debug', "Identificador do QR Code utilizado: {$qrcodeid}");

    // Monta a URL da API Pagou
    $api_url = "https://api.pagou.com.br/v1/pix/{$qrcodeid}/refund";
    log_message('debug', "URL da API para reembolso: {$api_url}");

    // Prepara o payload para requisição DELETE
    $payload_delete = [
        'amount'      => $refund_amount,
        'description' => $description,
        'reason'      => $reason
    ];
    log_message('debug', "Payload DELETE preparado: " . json_encode($payload_delete));

    // Carrega a API key do gateway no tbloptions (criptografada)
    // Verifica se payment_method é 'pix' ou 'boleto'
    if ($transaction->payment_method === 'pix') {
        $encryptedKey = get_option('paymentmethod_pagou_pix_api_token'); // PIX
    } else {
        $encryptedKey = get_option('paymentmethod_pagou_boleto_api_token'); // Boleto
    }

    // Descriptografa
    $this->load->library('encryption'); // garante que a library encryption está carregada
    if (!$encryptedKey) {
        log_message('error', 'API key Pagou não encontrada no tbloptions.');
        echo json_encode(['status' => 'error', 'message' => 'Configuração de API key ausente.']);
        return;
    }
    $apiToken = $this->encryption->decrypt($encryptedKey);
    if (!$apiToken) {
        log_message('error', 'Falha ao descriptografar a API key Pagou.');
        echo json_encode(['status' => 'error', 'message' => 'API key inválida ou não configurada.']);
        return;
    }
    log_message('debug', "API Token descriptografado: {$apiToken}");

    // Faz requisição DELETE manual usando cURL nativo
    log_message('info', 'Iniciando requisição DELETE para a API Pagou.');
    $ch = curl_init($api_url);
    curl_setopt($ch, CURLOPT_CUSTOMREQUEST, 'DELETE');
    curl_setopt($ch, CURLOPT_POSTFIELDS, json_encode($payload_delete));
    curl_setopt($ch, CURLOPT_RETURNTRANSFER, true);
    curl_setopt($ch, CURLOPT_HTTPHEADER, [
        'Content-Type: application/json',
        "X-API-KEY: {$apiToken}"
    ]);

    $response_raw = curl_exec($ch);
    $http_code    = curl_getinfo($ch, CURLINFO_HTTP_CODE);
    $error_msg    = curl_error($ch);
    curl_close($ch);

    log_message('debug', "Resposta bruta da API: {$response_raw}");
    log_message('debug', "HTTP Code: {$http_code} - cURL Error: {$error_msg}");

    // Analisa a resposta
    if ($http_code === 204) {
        log_message('info', "Reembolso aprovado pela API para transaction_id: {$transaction_id}. Atualizando status localmente.");

        // Atualiza status da transação p/ 'refunded'
        $this->pagou_model->update_transaction_status($transaction_id, 'refunded');
        log_message('info', "Status da transação {$transaction_id} atualizado para 'refunded'.");

        // Atualiza a fatura -> status=5 (Cancelado)
        $this->db->where('id', $transaction->invoice_id);
        $this->db->update('tblinvoices', ['status' => 5]);
        log_message('info', "Fatura ID {$transaction->invoice_id} atualizada p/ status=5 (Cancelado).");

        echo json_encode(['status' => 'success', 'message' => 'Reembolso realizado com sucesso!']);
    } else {
        // Falha ao reembolsar
        log_message('error', "Erro ao realizar o reembolso p/ transação ID: {$transaction_id}. HTTP CODE: {$http_code}, Erro cURL: {$error_msg}, Resposta API: {$response_raw}");
        echo json_encode(['status' => 'error', 'message' => 'Erro ao realizar reembolso. Verifique logs.']);
    }

    // Fim do processamento de reembolso
    log_message('info', 'Finalizando método reembolso_ajax.');
}



    /**
     * Endpoint para processar webhooks recebidos da API Pagou.
     *
     * @return void
     */
    public function webhook()
    {
        /* ============================
             Log de Acesso ao Webhook
           ============================ */
        /*
        log_message('debug', 'Webhook endpoint accessed');
        log_message('debug', 'Request method: ' . $_SERVER['REQUEST_METHOD']);
        log_message('debug', 'Headers: ' . json_encode(getallheaders()));
        log_message('debug', 'POST data: ' . json_encode($_POST));
        */

        /* ============================
             Obtenção e Validação do Payload
           ============================ */
        // Obtém o payload bruto
        $payload = file_get_contents('php://input');
        /*
        log_message('debug', 'Raw payload received: ' . $payload);
        */

        if (empty($payload)) {
            /*
            log_message('error', 'Payload is empty');
            */
            $this->output
                ->set_status_header(400)
                ->set_content_type('application/json')
                ->set_output(json_encode(['error' => 'Empty payload']))
                ->_display();
            exit;
        }

        // Verifica se o método é POST
        if ($_SERVER['REQUEST_METHOD'] !== 'POST') {
            /*
            log_message('error', 'Invalid HTTP method: ' . $_SERVER['REQUEST_METHOD']);
            */
            $this->output
                ->set_status_header(405)
                ->set_header('Allow: POST')
                ->set_content_type('application/json')
                ->set_output(json_encode(['error' => 'Method Not Allowed']))
                ->_display();
            exit;
        }

        // Decodifica o payload JSON
        $data = json_decode($payload);
        if (!$data) {
            /*
            log_message('error', 'Invalid JSON payload');
            */
            $this->output
                ->set_status_header(400)
                ->set_content_type('application/json')
                ->set_output(json_encode(['error' => 'Invalid JSON']))
                ->_display();
            exit;
        }
        /*
        log_message('debug', 'Decoded JSON payload: ' . json_encode($data));
        */

        /* ============================
             Início da Transação no Banco de Dados
           ============================ */
        $this->db->trans_begin();

        try {
            /* ============================
                 Busca da Transação
               ============================ */
            $transaction = null;

            if (isset($data->data->id)) {
                $payment_id = $data->data->id;
                /*
                log_message('debug', 'Payment ID received: ' . $payment_id);
                */
                $transaction = $this->db->where('transaction_id', $payment_id)
                                         ->or_where('qr_code', $payment_id)
                                         ->get('pagou_transactions')
                                         ->row();
            }

            if (!$transaction) {
                /*
                log_message('error', 'Transaction not found for Payment ID: ' . $payment_id);
                */
                $this->output
                    ->set_status_header(404)
                    ->set_content_type('application/json')
                    ->set_output(json_encode(['error' => 'Transaction not found']))
                    ->_display();
                exit;
            }

            /*
            log_message('debug', 'Transaction found: ' . json_encode($transaction));
            */

            /* ============================
                 Atualização da Transação
               ============================ */
            $update_data = [
                'status' => 'paid',
                'updated_at' => date('Y-m-d H:i:s')
            ];

            /*
            log_message('debug', 'Updating transaction with data: ' . json_encode($update_data));
            */

            $this->db->where('id', $transaction->id)
                     ->update('pagou_transactions', $update_data);

            /* ============================
                 Atualização do Status da Fatura
               ============================ */
            $this->db->where('id', $transaction->invoice_id)
                     ->update('tblinvoices', ['status' => 2]);

            /*
            log_message('debug', 'Invoice status updated to paid for ID: ' . $transaction->invoice_id);
            */

            /* ============================
                 Inserção do Registro de Pagamento
               ============================ */
            $payment_record = [
                'invoiceid' => $transaction->invoice_id,
                'amount' => $data->data->amount,
                'paymentmode' => 'pagou_boleto',
                'paymentmethod' => null,
                'date' => date('Y-m-d'),
                'daterecorded' => date('Y-m-d H:i:s'),
                'note' => "Pagador Final: {$data->data->payer->name}\nDocumento: {$data->data->payer->document}",
                'transactionid' => "{$data->data->id}"
            ];

            /*
            log_message('debug', 'Inserting payment record: ' . json_encode($payment_record));
            */

            $this->db->insert('tblinvoicepaymentrecords', $payment_record);

            /* ============================
                 Registro de Atividade de Pagamento
               ============================ */
            $invoice = $this->invoices_model->get($transaction->invoice_id);
            $description = 'Pagamento recebido via Pagou';
            if ($invoice) {
                $description .= ' para fatura #' . format_invoice_number($transaction->invoice_id);
            }
            /*
            log_activity($description);
            log_message('debug', 'Activity logged: ' . $description);
            */

            /* ============================
                 Verificação e Commit da Transação
               ============================ */
            if ($this->db->trans_status() === FALSE) {
                throw new Exception('Database transaction failed');
            }

            $this->db->trans_commit();
            /*
            log_message('debug', 'Transaction committed successfully');
            */

            /* ============================
                 Resposta de Sucesso
               ============================ */
            $this->output
                ->set_status_header(200)
                ->set_content_type('application/json')
                ->set_output(json_encode(['message' => 'Payment processed successfully']))
                ->_display();
            exit;

        } catch (Exception $e) {
            /* ============================
                 Rollback e Tratamento de Erros
               ============================ */
            $this->db->trans_rollback();
            /*
            log_message('error', 'Error processing webhook: ' . $e->getMessage());
            */
            $this->output
                ->set_status_header(500)
                ->set_content_type('application/json')
                ->set_output(json_encode(['error' => 'Internal server error']))
                ->_display();
            exit;
        }
    }

    /**
     * Verifica o status do pagamento com base no hash fornecido.
     *
     * @param string $hash Hash único da fatura.
     * @return void
     */
    public function check_payment($hash)
    {
        /*
        log_message('debug', 'Check payment called with hash: ' . $hash);
        */

        $this->db->where('hash', $hash);
        $invoice = $this->db->get('tblinvoices')->row();

        if (!$invoice) {
            /*
            log_message('error', 'Invoice not found for hash: ' . $hash);
            */
            echo json_encode(['status' => 'not_found']);
            return;
        }

        /*
        log_message('debug', 'Invoice found: ' . json_encode($invoice));
        */

        $this->db->where('invoice_id', $invoice->id);
        $this->db->order_by('date_created', 'DESC');
        $transaction = $this->db->get('pagou_transactions')->row();

        if ($transaction && $transaction->status === 'paid') {
            /*
            log_message('debug', 'Transaction status: paid for invoice ID: ' . $invoice->id);
            */
            echo json_encode(['status' => 'paid']);
        } else {
            /*
            log_message('debug', 'Transaction status: pending for invoice ID: ' . $invoice->id);
            */
            echo json_encode(['status' => 'pending']);
        }
    }

    /**
     * Obtém o status do pagamento com base no ID da transação.
     *
     * @param string $transaction_id ID da transação.
     * @return void
     */
    public function get_payment_status($transaction_id)
    {
        $status = $this->pagou_model->get_transaction_status($transaction_id);
        echo json_encode(['status' => $status]);
    }
}
?>
