<?php
defined('BASEPATH') or exit('No direct script access allowed');

/* ============================
     Inclusão de Dependências
   ============================ */
require_once(__DIR__ . '/pagou/Gateway_config.php');
require_once(__DIR__ . '/pagou/Transaction_handler.php');
require_once(__DIR__ . '/pagou/Api_client.php');
require_once(__DIR__ . '/pagou/Payment_processor.php');

/* ============================
     Definição da Classe Pagou_boleto_gateway
   ============================ */
class Pagou_boleto_gateway extends App_gateway
{
    protected $ci;
    private $transaction_handler;
    private $api_client;
    private $payment_processor;

    /* ============================
         Método Construtor
       ============================ */
    public function __construct()
    {
        parent::__construct();
        
        // Obtém a instância do CodeIgniter
        $this->ci = &get_instance();
        $this->ci->load->database();
        
        // Configurações do Gateway
        $this->setId('pagou_boleto');
        $this->setName('Pagou no Boleto');
        
        // Carrega as configurações
        $config = new Gateway_config();
        $this->setSettings($config->getSettings());

        // Inicializa os componentes
        $this->api_client = new Api_client($this->decryptSetting('api_token'));
        $this->transaction_handler = new Transaction_handler($this->ci, $this->api_client);
        $this->payment_processor = new Payment_processor($this->ci, $this->transaction_handler, $this->api_client, $this);
        
        // Adiciona filtro para gateways de pagamento
        hooks()->add_filter('app_payment_gateways', [$this, 'initMode']);
    }

    /* ============================
         Método process_payment
       ============================ */
    public function process_payment($data)
    {
        // Validar se a fatura foi passada corretamente
        if (empty($data['invoice'])) {
            // log_activity('Erro: Nenhuma fatura fornecida para o processamento do pagamento.');
            return false;
        }

        // Processar o pagamento usando o processador configurado
        try {
            $result = $this->payment_processor->process($data['invoice']);
            // log_activity('Pagamento processado com sucesso para a fatura ID: ' . $data['invoice']->id);
            return $result; // Retorna true se o pagamento foi processado com sucesso
        } catch (Exception $e) {
            // Capturar erros e registrar no log
            // log_activity('Erro ao processar o pagamento para a fatura ID: ' . $data['invoice']->id . '. Erro: ' . $e->getMessage());
            return false;
        }
    }

    /* ============================
         Método webhook
       ============================ */
    public function webhook()
    {
        // Disable CSRF for webhook
        //$this->ci->config->set_item('csrf_protection', FALSE);
        
        return $this->transaction_handler->handleWebhook();
    }
}
?>
