<?php
defined('BASEPATH') or exit('No direct script access allowed');

/**
 * Modelo Pagou_model
 *
 * Este modelo lida com operações relacionadas às transações do Pagou.
 */
class Pagou_model extends App_Model
{
    /**
     * Obtém o status de uma transação específica.
     *
     * @param int $transaction_id ID da transação.
     * @return string|null Retorna o status da transação ou null se não encontrado.
     */
    public function get_transaction_status($transaction_id)
    {
        $this->db->select('status');
        $this->db->from('tblpagou_transactions');
        $this->db->where('id', $transaction_id);
        $query = $this->db->get();

        if ($query->num_rows() > 0) {
            return $query->row()->status;
        }

        return null;
    }



    public function get_encrypted_api_token()
{
    // Altere 'pagou_pix' e 'api_token' conforme seu gateway
    $this->db->where('gateway', 'pagou_pix');
    $this->db->where('name', 'api_token');
    $row = $this->db->get('tblgateway_settings')->row();
    return $row ? $row->value : null; // 'value' está criptografado
}


    /**
     * Obtém as transações com base nos filtros fornecidos.
     *
     * @param array $filters Filtros para buscar transações (cliente, período, status).
     * @return array Retorna um array de transações.
     */
public function get_transactions($filters = [])
{
    $this->db->select('
        tblpagou_transactions.id,
        tblpagou_transactions.created_at,
        tblpagou_transactions.invoice_id,
        tblpagou_transactions.amount,
        tblpagou_transactions.status,
        tblpagou_transactions.updated_at,
        tblinvoices.clientid,
        tblinvoices.hash,
        tblclients.company
    ');
    $this->db->from(db_prefix() . 'pagou_transactions'); // Prefixo dinâmico
    $this->db->join(db_prefix() . 'invoices', db_prefix() . 'invoices.id = ' . db_prefix() . 'pagou_transactions.invoice_id', 'left');
    $this->db->join(db_prefix() . 'clients', db_prefix() . 'clients.userid = ' . db_prefix() . 'invoices.clientid', 'left');

    // Filtro por cliente
    if (!empty($filters['client'])) {
        $this->db->where(db_prefix() . 'clients.company', $filters['client']);
    }

    // Filtro por período
    if (!empty($filters['start_date']) && !empty($filters['end_date'])) {
        $this->db->where('DATE(' . db_prefix() . 'pagou_transactions.created_at) >=', $filters['start_date']);
        $this->db->where('DATE(' . db_prefix() . 'pagou_transactions.created_at) <=', $filters['end_date']);
    }

    // Filtro por status
    if (!empty($filters['status'])) {
        $this->db->where(db_prefix() . 'pagou_transactions.status', $filters['status']);
    }

    $this->db->order_by(db_prefix() . 'pagou_transactions.created_at', 'DESC');
    $query = $this->db->get();

    return $query->result_array();
}



    /**
     * Atualiza o status de uma transação específica.
     *
     * @param int $transaction_id ID da transação.
     * @param string $status Novo status da transação.
     * @return bool Retorna true se a atualização foi bem-sucedida, false caso contrário.
     */
    public function update_transaction_status($transaction_id, $status)
    {
        $this->db->where('id', $transaction_id);
        return $this->db->update('tblpagou_transactions', [
            'status' => $status,
            'updated_at' => date('Y-m-d H:i:s')
        ]);
    }

    /**
     * Obtém uma transação específica com base no ID.
     *
     * @param int $transaction_id ID da transação.
     * @return object|null Retorna o objeto da transação ou null se não encontrado.
     */
    public function get_transaction_by_id($transaction_id)
    {
        $this->db->select('*');
        $this->db->from('tblpagou_transactions');
        $this->db->where('id', $transaction_id);
        $query = $this->db->get();

        if ($query->num_rows() > 0) {
            return $query->row();
        }

        return null;
    }
}
