<?php
defined('BASEPATH') or exit('No direct script access allowed');

/*
Module Name: Pagou Integração Perfex CRM
Description: Gateway de pagamento www.pagou.com.br, PIX & Boleto para Perfex CRM
Version: 1.1.0
Requires at least: 2.3.4
Author: Nando Cardoso - Connect Designers
Author URI: https://connectdesigners.com.br
*/

// Inclui helpers
require_once __DIR__ . '/helpers/pagou_helper.php';

// Obtém a instância do CodeIgniter
$CI = &get_instance();
$CI->load->helper('url');

// Registra as permissões do módulo
hooks()->add_action('admin_init', 'pagou_module_permissions');

function pagou_module_permissions()
{
    $permissions = [];

    $permissions['capabilities'] = [
        'access_pix_avulso' => 'Acessar PIX Avulso',
        'access_reembolso'  => 'Acessar Reembolso de Pagamentos',
    ];

    register_staff_capabilities('pagou_module', $permissions, _l('Pagou Integração'));
}

// Verifica se a rota é para o webhook do Pagou
if ($CI->uri->segment(1) === 'pagou' && $CI->uri->segment(2) === 'webhook') {
    require_once __DIR__ . '/controllers/Pagou.php';
    $pagou = new Pagou();
    $pagou->webhook();
    exit;
}

// Registra o hook de ativação
register_activation_hook('pagou', 'pagou_activation_hook');

// Registra os gateways de pagamento
register_payment_gateway('pagou_boleto_gateway', 'pagou');
register_payment_gateway('pagou_pix_gateway', 'pagou');

// Adiciona hook para cancelamento de boleto
hooks()->add_action('invoice_marked_as_cancelled', 'cancel_pagou_boleto');

// Registra o cronjob no Perfex CRM
hooks()->add_action('after_cron_run', 'process_pagou_boleto_invoices');

// Adiciona os itens do menu com controle de permissão
hooks()->add_action('admin_init', function () {
    $CI = &get_instance();

    if (has_permission('pagou', '', 'view')) {
        $CI->app_menu->add_sidebar_menu_item('pagou-menu', [
            'name' => 'Pagou',
            'icon' => 'fa fa-money',
            'position' => 10,
        ]);

        // PIX Avulso - Controle de Acesso
        if (staff_can('access_pix_avulso', 'pagou_module')) {
            $CI->app_menu->add_sidebar_children_item('pagou-menu', [
                'slug' => 'pagou-pix-avulso',
                'name' => 'PIX Avulso',
                'href' => admin_url('pagou/pix_avulso'),
                'position' => 5,
            ]);
        }

        // Reembolso de Pagamentos - Controle de Acesso
        if (staff_can('access_reembolso', 'pagou_module')) {
            $CI->app_menu->add_sidebar_children_item('pagou-menu', [
                'slug' => 'pagou-cobrancas-emitidas',
                'name' => 'Reembolso de Pagamentos',
                'href' => admin_url('pagou/cobrancas_emitidas'),
                'position' => 10,
            ]);
        }
    }
});

/**
 * Hook de ativação do módulo Pagou
 */
function pagou_activation_hook()
{
    require_once __DIR__ . '/install.php';
}

// Adiciona link de ação ao módulo
hooks()->add_filter('module_pagou_action_links', 'module_pagou_action_links');

/**
 * Adiciona links de ação ao módulo Pagou
 *
 * @param array $actions Links de ação existentes.
 * @return array Links de ação atualizados.
 */
function module_pagou_action_links($actions)
{
    $actions[] = '<a href="https://liquidasp.com.br/shortly/PagouAPI" target="_blank">CONTA GRÁTIS PAGOU.COM.BR</a>';
    return $actions;
}

/**
 * Processa faturas com pagamento via Pagou Boleto
 */
function process_pagou_boleto_invoices()
{
    $CI = &get_instance();

    $CI->db->where("allowed_payment_modes LIKE '%\"pagou_boleto\"%' ");
    $CI->db->where("(invoice_pagou IS NULL OR invoice_pagou = 0)");
    $invoices = $CI->db->get(db_prefix() . 'invoices')->result();

    if ($invoices) {
        $gateway = new Pagou_boleto_gateway();

        foreach ($invoices as $invoice) {
            $data = ['invoice' => $invoice];
            $boleto_created = $gateway->process_payment($data);

            if ($boleto_created) {
                $CI->db->where('id', $invoice->id);
                $CI->db->update(db_prefix() . 'invoices', ['invoice_pagou' => 1]);
            }
        }
    }
}
