<?php defined('BASEPATH') or exit('No direct script access allowed'); ?>
<?php init_head(); ?>

<?php
// Início do processamento da view de cobranças emitidas
log_message('info', 'Carregando a view "Cobranças Emitidas Invoice x Pagou".');
?>

<div id="wrapper">
    <div class="content">
        <div class="row">
            <div class="col-md-12">
                <h3 class="text-center" style="font-weight: bold;">Cobranças Emitidas Invoice x Pagou</h3>
                <hr>

                <?php
                log_message('info', 'Iniciando consulta às transações com status "paid" ou "2".');

                // =========================================
                // CONSULTA: UNIFICA TBLPAGOU_TRANSACTIONS e TBLPAGOU_TRANSACTIONS_PIX
                // APENAS com status 'paid' OU '2'
                // =========================================

                // 1. Busca transações na tblpagou_transactions (status = 'paid' ou '2')
                log_message('debug', 'Consultando tblpagou_transactions com status "paid" ou "2".');
                $this->db->select('
                    t.id as transaction_id,
                    t.created_at,
                    t.invoice_id,
                    t.amount,
                    t.status,
                    t.updated_at,
                    inv.hash,
                    inv.clientid,
                    c.company as client_company
                ');
                $this->db->from('tblpagou_transactions as t');
                // JOIN tblinvoices
                $this->db->join('tblinvoices as inv', 'inv.id = t.invoice_id', 'left');
                // JOIN tblclients
                $this->db->join('tblclients as c', 'c.userid = inv.clientid', 'left');
                // Filtrar status = 'paid' ou '2'
                $this->db->where_in('t.status', ['paid', '2']);
                $transactionsA = $this->db->get()->result_array();
                log_message('info', 'Consulta em tblpagou_transactions finalizada. Número de resultados: ' . count($transactionsA));

                // 2. Busca transações na tblpagou_transactions_pix (status = 'paid' ou '2')
                log_message('debug', 'Consultando tblpagou_transactions_pix com status "paid" ou "2".');
                $this->db->select('
                    pix.id as transaction_id,
                    pix.date_created as created_at,
                    pix.invoice_id,
                    pix.amount_final as amount,
                    pix.status,
                    pix.data_pagamento as updated_at,
                    inv.hash,
                    inv.clientid,
                    c.company as client_company
                ');
                $this->db->from('tblpagou_transactions_pix as pix');
                // JOIN tblinvoices
                $this->db->join('tblinvoices as inv', 'inv.id = pix.invoice_id', 'left');
                // JOIN tblclients
                $this->db->join('tblclients as c', 'c.userid = inv.clientid', 'left');
                // Filtrar status = 'paid' ou '2'
                $this->db->where_in('pix.status', ['paid', '2']);
                $transactionsB = $this->db->get()->result_array();
                log_message('info', 'Consulta em tblpagou_transactions_pix finalizada. Número de resultados: ' . count($transactionsB));

                // 3. Mescla os resultados
                log_message('debug', 'Mesclando resultados das duas consultas.');
                $transactions = array_merge($transactionsA, $transactionsB);
                log_message('info', 'Número total de transações após mesclagem: ' . count($transactions));

                // Ordena por data de criação desc
                log_message('debug', 'Ordenando transações por data de criação descendente.');
                usort($transactions, function($a, $b) {
                    return strtotime($b['created_at']) - strtotime($a['created_at']);
                });
                log_message('info', 'Transações ordenadas.');
                ?>

                <!-- Tabela de resultados -->
                <table class="table table-striped">
                    <thead>
                        <tr>
                            <th>Data Invoice</th>
                            <th>Invoice</th>
                            <th>Cliente</th>
                            <th>Valor</th>
                            <th>Status</th>
                            <th>Data Pagamento</th>
                            <th>Ação</th>
                        </tr>
                    </thead>
                    <tbody>
                        <?php if (!empty($transactions)) : ?>
                            <?php
                            log_message('info', 'Renderizando tabela com ' . count($transactions) . ' transações.');
                            ?>
                            <?php foreach ($transactions as $transaction) : ?>
                                <?php
                                // Log de início do processamento de cada transação
                                log_message('debug', 'Processando transação ID: ' . $transaction['transaction_id']);

                                // Data Invoice (created_at)
                                $data_invoice = !empty($transaction['created_at']) 
                                    ? _d($transaction['created_at']) 
                                    : '---';
                                log_message('debug', 'Data Invoice: ' . $data_invoice);

                                // Link da invoice
                                $invoice_link = site_url('invoice/' . $transaction['invoice_id'] . '/' . $transaction['hash']);
                                log_message('debug', 'Link da Invoice: ' . $invoice_link);

                                // Cliente e link
                                $client_name = $transaction['client_company'] ?: '---';
                                $client_link = admin_url('clients/client/' . ($transaction['clientid'] ?? '0'));
                                log_message('debug', 'Nome do Cliente: ' . $client_name . ' | Link: ' . $client_link);

                                // Valor formatado
                                $valor_formatado = 'R$' . number_format($transaction['amount'], 2, ',', '.');
                                log_message('debug', 'Valor Formatado: ' . $valor_formatado);

                                // Interpretação do status
                                // 'paid' ou '2' significa "Pago"
                                $status_db = (string)$transaction['status'];
                                $status_display = ($status_db === 'paid' || $status_db === '2') ? 'Pago' : ucfirst($status_db);
                                log_message('debug', 'Status da Transação: ' . $status_display);

                                // Data Pagamento
                                $data_pagamento = !empty($transaction['updated_at'])
                                    ? _dt($transaction['updated_at'])
                                    : '---';
                                log_message('debug', 'Data Pagamento: ' . $data_pagamento);
                                ?>
                                <tr>
                                    <td><?= $data_invoice; ?></td>
                                    <td>
                                        <a href="<?= $invoice_link; ?>" target="_blank">
                                            #<?= $transaction['invoice_id']; ?>
                                        </a>
                                    </td>
                                    <td>
                                        <a href="<?= $client_link; ?>" target="_blank">
                                            <?= htmlspecialchars($client_name, ENT_QUOTES); ?>
                                        </a>
                                    </td>
                                    <td><?= $valor_formatado; ?></td>
                                    <td><?= $status_display; ?></td>
                                    <td><?= $data_pagamento; ?></td>
                                    <td>
                                        <!-- Somente exibe reembolso se for pago -->
                                        <?php if ($status_db === 'paid' || $status_db === '2'): ?>
                                            <?php
                                            log_message('debug', 'Exibindo botão de reembolso para a transação ID: ' . $transaction['transaction_id']);
                                            ?>
                                            <button class="btn btn-success btn-sm"
                                                onclick="refundTransaction(
                                                    <?= $transaction['transaction_id']; ?>,
                                                    '<?= addslashes($client_name); ?>',
                                                    <?= $transaction['invoice_id']; ?>,
                                                    <?= $transaction['amount']; ?>
                                                )">
                                                Reembolsar
                                            </button>
                                        <?php else: ?>
                                            <?php
                                            log_message('debug', 'Transação ID: ' . $transaction['transaction_id'] . ' não está paga. Exibindo status "Não Pago".');
                                            ?>
                                            <span class="text-muted">Não Pago</span>
                                        <?php endif; ?>
                                    </td>
                                </tr>
                            <?php endforeach; ?>
                        <?php else : ?>
                            <?php
                            log_message('warning', 'Nenhuma transação paga encontrada para exibição.');
                            ?>
                            <tr>
                                <td colspan="7" class="text-center">Nenhuma transação paga encontrada.</td>
                            </tr>
                        <?php endif; ?>
                    </tbody>
                </table>

            </div>
        </div>
    </div>
</div>

<!-- Modal Reembolso: Removemos o form e faremos DELETE direto via JS/AJAX -->
<div class="modal fade" id="modalReembolso" tabindex="-1" role="dialog" aria-labelledby="modalReembolsoLabel" aria-hidden="true">
    <div class="modal-dialog modal-lg" role="document">
        <div class="modal-content">
            <div class="modal-header">
                <h2 class="modal-title text-center" id="modalReembolsoLabel" style="font-weight: bold; font-size: 2rem;">
                    Reembolso de Pagamento
                </h2>
                <button type="button" class="close" data-dismiss="modal" aria-label="Close">
                    <span aria-hidden="true">&times;</span>
                </button>
            </div>
            <div class="modal-body">
                <!-- Em vez de um <form>, exibimos só os dados e um botão "Confirmar" que chama AJAX DELETE. -->
                <p class="text-center"><strong>Cliente:</strong> <span id="reembolsoCliente"></span></p>
                <p class="text-center"><strong>Fatura:</strong> <span id="reembolsoInvoice"></span></p>
                <hr>
                <p class="text-center" style="font-size: 1rem; font-style: italic;">
                    O reembolso é destinado exclusivamente para pagamentos realizados via PIX ou Boleto PIX.
                </p>
                <hr>
                <div class="form-group">
                    <label>Valor do Reembolso:</label>
                    <p><strong>Valor Total:</strong> R$<span id="valorTotalSpan"></span></p>
                </div>
                <div class="form-group">
                    <label for="reason">Motivo do Cancelamento:</label>
                    <textarea id="refundReason" class="form-control" rows="3" required></textarea>
                </div>
                <hr>
                <div class="form-group text-center">
                    <input type="checkbox" id="confirmRefund" required>
                    <label for="confirmRefund">
                        Ao clicar em 'Confirmar Reembolso', o processo não poderá ser cancelado!
                    </label>
                </div>
                <div class="form-group text-center">
                    <button class="btn btn-primary" id="btnConfirmarReembolso" disabled>Confirmar Reembolso</button>
                </div>
            </div>
        </div>
    </div>
</div>

<?php init_tail(); ?>

<script>
    /**
     * refundTransaction: abre modal e preenche dados do reembolso.
     * A requisição DELETE será feita via JavaScript para o controlador (Pagou.php),
     * que então chamará a API Pagou por cURL.
     */
    function refundTransaction(transactionId, clientName, invoiceId, amount) {
        console.log('Abrindo modal de reembolso para a transação ID:', transactionId);
        // Preenche dados no modal
        $('#transaction_id').val(transactionId);
        $('#reembolsoCliente').text(clientName);
        $('#reembolsoInvoice').text('#' + invoiceId);
        $('#valorTotalSpan').text(parseFloat(amount).toFixed(2).replace('.', ','));
        $('#refundReason').val('');
        $('#confirmRefund').prop('checked', false);
        $('#btnConfirmarReembolso').prop('disabled', true);

        $('#modalReembolso').modal('show');

        // Evento de click no botão "Confirmar Reembolso"
        $('#btnConfirmarReembolso').off('click').on('click', function() {
            let reason = $('#refundReason').val().trim();
            if (!reason) {
                alert('Informe o motivo do reembolso.');
                return;
            }
            if (!confirm('Tem certeza que deseja reembolsar essa transação?')) {
                return;
            }
            // Faz requisição DELETE via fetch
            let endpoint = "<?= admin_url('pagou/reembolso_ajax'); ?>?transaction_id=" + transactionId;
            let payload = {
                amount: parseFloat(amount),
                description: reason,
                reason: 1  // reason fixo = 1
            };

            fetch(endpoint, {
                method: 'DELETE',
                headers: {
                    'Content-Type': 'application/json'
                },
                body: JSON.stringify(payload)
            })
            .then(response => response.json())
            .then(data => {
                if (data.status === 'success') {
                    alert('Reembolso realizado com sucesso!');
                    location.reload();
                } else {
                    alert('Erro ao reembolsar: ' + (data.message || 'Verifique logs.'));
                }
            })
            .catch(err => {
                console.error('Erro ao chamar reembolso_ajax:', err);
                alert('Falha na requisição de reembolso.');
            });
        });
    }

    // Habilita "Confirmar Reembolso" somente após marcar confirmRefund
    $('#confirmRefund').on('change', function () {
        $('#btnConfirmarReembolso').prop('disabled', !this.checked);
    });
</script>
